==> worlds_pokemon_frlg-0.0.1.tar.gz: worlds_pokemon_frlg-0.0.1/src/worlds/pokemon_frlg/docs/rom changes.md <==
## Base Rom Changes

* The Options Menu has been expanded with many new options and multiple pages that can be cycled between using the R and L buttons
  * General Options
    * Text Speed: Sets the speed at which text displays
    * Turbo A: Sets whether holding down A will auto advance text
    * Auto Run: Sets whether you will run by default without needing to hold B
    * Button Mode: Sets how the R and L buttons behave
    * Frame: Sets the frame used for text boxes
  * Battle Options
    * Battle Scene: Sets whether battle animations play or not
    * Battle Style: Sets whether you are asked to swap Pokémon when the opponent is sending out a new Pokémon 
    * Show Effectiveness: Sets whether move effectiveness is shown in the move detail panel in battle
    * Experience: Sets how much exp you gain in battle
  * Sound Options
    * Sound: Sets whether to use Mono or Stereo
    * Low HP Beep: Sets whether the low HP beep plays when your Pokémon is at low health
    * Skip Fanfares: Sets whether you can skip fanfares by pressing the B button
    * Bike Music: Sets whether the bicycle music will play when you are on the bike
    * Surf Music: Sets whether the surfing music will play when you are surfing
  * Quality of Life Options
    * Guaranteed Catch: Sets whether Poké Balls are guaranteeed to catch Pokémon or not
    * Encounter Rates: Sets whether encounter rates are vanilla or normalized
    * Blind Trainers: Sets whether trainers will approach the player when you enter their line of sight
    * Item Messages: Sets what type of items will display messages in game when received from Archipelago
* Pressing the START button while you are hovering over a move in battle will open up a textbox with more details about the move including power, accuracy, priority, etc. Pressing any of START, A, or B will close this textbox
* Damage type icons have been added to moves in the move summary screen and in battle
* Cycling and running is allowed in most maps
* The game will prompt you to use another repel when one runs out
* Bag and PC space was expanded
* It is possible to teach over HM moves
* The Pokédex starts in national mode
* The Pokémon Center Nurse initial dialogue is removed
* The fishing minigame is always successful at finding a catch, only requires one round, and will always show four dots
* The sliding animation for trainers and wild pokémon at the start of a battle runs at double speed
* Pokémon are never disobedient
* When moving in the overworld, set the input priority based on the most recently pressed direction rather than by some
predetermined priority
* Increased Safari Zone steps from 600 to 60000
* You can fly between Kanto and the Sevii Islands
* The text displayed when a Trainer is about to send out a new Pokémon has been shortened so that you can still see the name of the Pokémon when deciding if you want to swap
* Increased the rate at which a Pokémon's HP drains in battle to be based on the Pokémon's max HP
* Added a GO HOME option to the menu that teleports you to your starting location
* All evolution items have been turned into key items that can be used repeatedly. A new evolution item, the Link Cable, has been added to the game
* A new page has been added to Pokémon's Dex entires that lists out the areas where you can find them and what they can evolve into
* Talking to the Mystery Gift Man on the 2nd floor of any Pokémon Center will allow you to respawn any static encounters you haven't caught yet
* Talking to the Wireless Club Attendant (left) on the 2nd floor of any Pokémon Center will let you fight a random uncatchable Pokémon in order to grind exp and money
* Talking to the Direct Corner Attendant (right) on the 2nd floor of any Pokémon Center will allow you to purchase various consumable items you have already found
* The Pikachu tutorial in the intro is skipped
* The intro sequence of the game has been changed:
  * You now choose your starter Pokémon in the intro after you name your rival
  * Your spawn point is in front of your house in Pallet Town instead of in your room
  * The Professor Oak scene in Pallet Town where he takes you to his lab in removed
  * Professor Oak's Lab starts at the point where you need to do the first rival battle. The trigger for the rival battle has been removed and the battle can be initiated by talking to him
* The Old Man catching tutorial is skipped
* Miguel's position in Mt. Moon will change based on which side you enter from
* Both fossils in Mt. Moon will give you the same item so it doesn't matter which one you pick up. The second fossil can be obtained in the Pokémon Lab after you have revived a certain number of fossils
* The Team Rocket Grunt on Route 24 won't give you your reward until after the battle
* The S.S. Anne will never depart
* The Vermilion Gym puzzle doesn't reset if you get the second trash can switch wrong
* Updated the coin purchase NPC at the Celadon Game Corner:
  * Changed the 50 coin purchase to a 100 coin purchase
  * Added a 1000 and 1500 coin purchase option
  * Made it so that you can purchase coins even if it would put you over the max coins of 9999
* The Saffron City guards will block your way from both directions
* You are able to pick up both Pokémon in the Saffron Dojo
* Your Rival in Silph Co. will give you the new Link Cable item
* The Seafoam Islands entrances on Route 20 have been swapped so that you can travel from Cinnabar to Fuchsia
* Seafoam Islands B3F has been changed so that there is a path you can take to cross from the Fuchsia side to the Cinnabar side using surf and waterfall
* The fossil Pokémon can be obtained immediately after giving them to the scientist in the Pokémon Lab without needing to reload the map
* Only the last guard on Route 23 will check for badges or gyms
* Professor Oak will give you the Mystic and Aurora Ticket in the Hall of Fame
* Much of the Sevii Islands has been reworked:
  * The cutscene after Cinnabar Gym where Bill takes you to the Sevii Islands has been removed. Instead, Bill will immediately be waiting in the Pokémon Center to take you to One Island. If Kanto Only is on, Bill will take you to Vermilion City instead
  * The Tri Pass allows you to sail to the 1-3 Islands and the Rainbow Pass allows you to sail to the 4-7 Islands from Vermilion City
  * You will never be trapped on the Sevii Islands and your PC will never be disabled there
  * Several cutscenes in the One Island Pokémon Center have been reworked or removed
  * You must deliver the Meteorite to Lostelle's dad before you can give Celio the Ruby and before the Team Rocket Grunts at Mt. Ember can be fought
  * You must free the Pokémon from the Rocket Warehouse before you can give Celio the Sapphire
  * The initial cutscene with the biker at the Two Island Game Corner has been removed
  * Three Isle Path is open immediately
  * The Rocket Warehouse requires both passwords to open
  * You no longer need to have a max friendship Pokémon in order to get the Togepi Egg from the Gentleman in the Water Labyrinth
  * A new event was added on Seven Island where you can get a Scanner in the Tanoby Ruins after solving the puzzle in the Tanoby Key. The Scanner can be traded to the Scientist in town for a Deep Sea Scale and Deep Sea Tooth
* Evolutions that would be impossible have been changed:
  * Regular trade evolutions now evolve by using the Link Cable on them
  * Held item trade evolutions now evolve by using the Link Cable on them while they are holding the required item
  * Eevee can be given a Sun Stone or Moon Stone to evolve into Espeon or Umbreon respectively
  * Feebas evolves into Milotic by using the Link Cable on them while they are holding a Heart Scale

==> worlds_pokemon_frlg-1.0.1.tar.gz: worlds_pokemon_frlg-1.0.1/src/worlds/pokemon_frlg/docs/rom changes.md <==
## Base Rom Changes

* The Options Menu has been expanded with many new options and multiple pages that can be cycled between using the R and L buttons
  * General Options
    * Text Speed: Sets the speed at which text displays
    * Turbo Button: Sets what button can be held down to auto advance text
    * Auto Run: Sets whether you will run by default without needing to hold B
    * Button Mode: Sets how the R and L buttons behave
    * Frame: Sets the frame used for text boxes
  * Battle Options
    * Battle Scene: Sets whether battle animations play or not
    * Battle Style: Sets whether you are asked to swap Pokémon when the opponent is sending out a new Pokémon 
    * Show Effectiveness: Sets whether move effectiveness is shown in the move detail panel in battle
    * Experience Multiplier: Sets how much exp you gain in battle
    * Experience Distribution: Sets how exp should be distributed (Gen III, Gen VI, or Gen VIII)
  * Sound Options
    * Sound: Sets whether to use Mono or Stereo
    * Low HP Beep: Sets whether the low HP beep plays when your Pokémon is at low health
    * Skip Fanfares: Sets whether you can skip fanfares by pressing the B button
    * Bike Music: Sets whether the bicycle music will play when you are on the bike
    * Surf Music: Sets whether the surfing music will play when you are surfing
  * Quality of Life Options
    * Guaranteed Catch: Sets whether Poké Balls are guaranteeed to catch Pokémon or not
    * Guaranteed Run: Sets whether you are guaranteed to run from battle (trapping moves and abilities will still prevent you from running)
    * Encounter Rates: Sets whether encounter rates are vanilla or normalized
    * Blind Trainers: Sets whether trainers will approach the player when you enter their line of sight
    * Skip Nicknames: Sets whether the prompt for nicknaming your Pokémon will be skipped
    * Item Messages: Sets what type of items will display messages in game when received from Archipelago
* Pressing the START button while you are hovering over a move in battle will open up a textbox with more details about the move including power, accuracy, priority, etc. Pressing any of START, A, or B will close this textbox
* Damage type icons have been added to moves in the move summary screen and in battle
* Cycling and running is allowed in most maps
* The game will prompt you to use another repel when one runs out
* Bag and PC space was expanded
* It is possible to teach over HM moves
* The Pokédex starts in national mode
* The Pokémon Center Nurse initial dialogue is removed
* The fishing minigame is always successful at finding a catch, only requires one round, and will always show four dots
* The sliding animation for trainers and wild pokémon at the start of a battle runs at double speed
* Pokémon are never disobedient
* When moving in the overworld, set the input priority based on the most recently pressed direction rather than by some
predetermined priority
* Increased Safari Zone steps from 600 to 60000
* You can fly between Kanto and the Sevii Islands
* The text displayed when a Trainer is about to send out a new Pokémon has been shortened so that you can still see the name of the Pokémon when deciding if you want to swap
* Increased the rate at which a Pokémon's HP drains in battle to be based on the Pokémon's max HP
* Added a GO HOME option to the menu that teleports you to your starting location
* The Exp. Share has been converted to a key item that can be turned on/off by using it in the bag. The way Exp is distributed when it's on is determined by the Experience Distribution game option
* All evolution items have been turned into key items that can be used repeatedly. A new evolution item, the Link Cable, has been added to the game
* A new page has been added to Pokémon's Dex entires that lists out the areas where you can find them and what they can evolve into
* Talking to the Mystery Gift Man on the 2nd floor of any Pokémon Center will allow you to respawn any static encounters you haven't caught yet
* Talking to the Wireless Club Attendant (left) on the 2nd floor of any Pokémon Center will let you fight a random uncatchable Pokémon in order to grind exp and money
* Talking to the Direct Corner Attendant (right) on the 2nd floor of any Pokémon Center will allow you to purchase various consumable items you have already found
* The Pikachu tutorial in the intro is skipped
* The intro sequence of the game has been changed:
  * You now choose your starter Pokémon in the intro after you name your rival
  * Your spawn point is in front of your house in Pallet Town instead of in your room
  * The Professor Oak scene in Pallet Town where he takes you to his lab in removed
  * Professor Oak's Lab starts at the point where you need to do the first rival battle. The trigger for the rival battle has been removed and the battle can be initiated by talking to him
* The Old Man catching tutorial is skipped
* Miguel's position in Mt. Moon will change based on which side you enter from
* Both fossils in Mt. Moon will give you the same item so it doesn't matter which one you pick up. The second fossil can be obtained in the Pokémon Lab after you have revived a certain number of fossils
* The Team Rocket Grunt on Route 24 won't give you your reward until after the battle
* The S.S. Anne will never depart
* The Vermilion Gym puzzle doesn't reset if you get the second trash can switch wrong
* Updated the coin purchase NPC at the Celadon Game Corner:
  * Changed the 50 coin purchase to a 100 coin purchase
  * Added a 1000 and 1500 coin purchase option
  * Made it so that you can purchase coins even if it would put you over the max coins of 9999
* The checks for needing the Bicycle for Cycling Road now happen once you enter Cycling Road instead of in the Gates before it
* The Saffron City guards will block your way from both directions
* You are able to pick up both Pokémon in the Saffron Dojo
* Your Rival in Silph Co. will give you the new Link Cable item
* The Seafoam Islands entrances on Route 20 have been swapped so that you can travel from Cinnabar to Fuchsia
* Seafoam Islands B3F has been changed so that there is a path you can take to cross from the Fuchsia side to the Cinnabar side using surf and waterfall
* The fossil Pokémon can be obtained immediately after giving them to the scientist in the Pokémon Lab without needing to reload the map
* Only the last guard on Route 23 will check for badges or gyms
* Professor Oak will give you the Mystic and Aurora Ticket in the Hall of Fame
* Much of the Sevii Islands has been reworked:
  * The cutscene after Cinnabar Gym where Bill takes you to the Sevii Islands has been removed. Instead, Bill will immediately be waiting in the Pokémon Center to take you to One Island. If Kanto Only is on, Bill will take you to Vermilion City instead
  * The Tri Pass allows you to sail to the 1-3 Islands and the Rainbow Pass allows you to sail to the 4-7 Islands from Vermilion City
  * You will never be trapped on the Sevii Islands and your PC will never be disabled there
  * Several cutscenes in the One Island Pokémon Center have been reworked or removed
  * You must deliver the Meteorite to Lostelle's dad before you can give Celio the Ruby and before the Team Rocket Grunts at Mt. Ember can be fought
  * You must free the Pokémon from the Rocket Warehouse before you can give Celio the Sapphire
  * The initial cutscene with the biker at the Two Island Game Corner has been removed
  * Three Isle Path is open immediately
  * The Rocket Warehouse requires both passwords to open
  * You no longer need to have a max friendship Pokémon in order to get the Togepi Egg from the Gentleman in the Water Labyrinth
  * A new event was added on Seven Island where you can get a Scanner in the Tanoby Ruins after solving the puzzle in the Tanoby Key. The Scanner can be traded to the Scientist in town for a Deep Sea Scale and Deep Sea Tooth
* Evolutions that would be impossible have been changed:
  * Regular trade evolutions now evolve by using the Link Cable on them
  * Held item trade evolutions now evolve by using the Link Cable on them while they are holding the required item
  * Eevee can be given a Sun Stone or Moon Stone to evolve into Espeon or Umbreon respectively
  * Feebas evolves into Milotic by using the Link Cable on them while they are holding a Heart Scale
